package io.github.p2vman.profiling;


public interface Profiler {
    /**
     * Запускает отсчет времени для нового блока.
     *
     * @param name название блока кода
     */
    void push(String name);

    /**
     * Останавливает отсчет времени для последнего блока.
     *
     * @return название блока, который был остановлен
     */
    String pop();

    /**
     * Возвращает название текущего активного блока без остановки его выполнения.
     *
     * @return название текущего блока
     */
    String peek();

    /**
     * Получает общее время выполнения для указанного блока и удаляет запись.
     *
     * @param name название блока кода
     * @return время в миллисекундах
     */
    long getElapsedTimeAndRemove(String name);

    /**
     * Получает общее время выполнения для указанного блока без удаления записи.
     *
     * @param name название блока кода
     * @return время в миллисекундах
     */
    long getElapsedTime(String name);
}